==> thx-l10n-0.0.1.tar.gz: thx-l10n-0.0.1/thx/l10n/api/version1/serializers.py <==
# -*- coding: utf-8 -*-

from rest_framework import serializers

from ... import models
from thx.api.serializers import (
    ThuxListSerializerMixin, ThuxRetrieveSerializerMixin, ThuxCreateSerializerMixin,
    ThuxUpdateSerializerMixin, ThuxPartialUpdateSerializerMixin, ThuxStatusSerializerMixin,
    ThuxEnableSerializerMixin, ThuxDisableSerializerMixin
)


# COUNTRY
class CountrySerializer(serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_l10n_country'
        model = models.Country
        fields = '__all__'


class CountryListSerializer(ThuxListSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_l10n_country_list'
        model = models.Country
        fields = '__all__'

    def get_field_names(self, *args, **kwargs):
        profile = self.context.get('view').kwargs['profile']
        fields = super().get_field_names(*args, **kwargs)
        if profile == '':
            return fields
        return []


class CountryRetrieveSerializer(ThuxRetrieveSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_l10n_country_retrieve'
        model = models.Country
        fields = '__all__'

    def get_field_names(self, *args, **kwargs):
        profile = self.context.get('view').kwargs['profile']
        fields = super().get_field_names(*args, **kwargs)
        if profile == '':
            return fields
        return []


class CountryCreateSerializer(ThuxCreateSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_l10n_country_create'
        model = models.Country
        exclude = ('date_create', 'date_last_modify', 'creator', 'last_modifier')

    def get_field_names(self, *args, **kwargs):
        profile = self.context.get('view').kwargs['profile']
        fields = super().get_field_names(*args, **kwargs)
        if profile == '':
            return fields
        return []

    def to_representation(self, instance):
        return CountryListSerializer(instance, context=self.context).data


class CountryUpdateSerializer(ThuxUpdateSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_l10n_country_update'
        model = models.Country
        exclude = ('date_create', 'date_last_modify', 'creator', 'last_modifier')

    def get_field_names(self, *args, **kwargs):
        profile = self.context.get('view').kwargs['profile']
        fields = super().get_field_names(*args, **kwargs)
        if profile == '':
            return fields
        return []

    def to_representation(self, instance):
        return CountryRetrieveSerializer(instance, context=self.context).data


class CountryPartialUpdateSerializer(ThuxPartialUpdateSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_l10n_country_partial_update'
        model = models.Country
        exclude = ('date_create', 'date_last_modify', 'creator', 'last_modifier')

    def get_field_names(self, *args, **kwargs):
        profile = self.context.get('view').kwargs['profile']
        fields = super().get_field_names(*args, **kwargs)
        if profile == '':
            return fields
        return []

    def to_representation(self, instance):
        return CountryRetrieveSerializer(instance, context=self.context).data


class CountryEnableSerializer(ThuxEnableSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_l10n_country_enable'
        model = models.Country
        fields = ()

    def update(self, instance, validated_data):
        instance.status = 1
        instance.save()
        return instance

    def to_representation(self, instance):
        return CountryRetrieveSerializer(instance, context=self.context).data


class CountryDisableSerializer(ThuxDisableSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_l10n_country_disable'
        model = models.Country
        fields = ()

    def update(self, instance, validated_data):
        instance.status = 0
        instance.save()
        return instance

    def to_representation(self, instance):
        return CountryRetrieveSerializer(instance, context=self.context).data


# ADMINISTRATIVE AREA
class AdministrativeAreaSerializer(serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_l10n_administrative_area'
        model = models.AdministrativeArea
        fields = '__all__'


class AdministrativeAreaListSerializer(ThuxListSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_l10n_administrative_area_list'
        model = models.AdministrativeArea
        fields = '__all__'

    def get_field_names(self, *args, **kwargs):
        profile = self.context.get('view').kwargs['profile']
        fields = super().get_field_names(*args, **kwargs)
        if profile == '':
            return fields
        return []


class AdministrativeAreaRetrieveSerializer(ThuxRetrieveSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_l10n_administrative_area_retrieve'
        model = models.AdministrativeArea
        fields = '__all__'

    def get_field_names(self, *args, **kwargs):
        profile = self.context.get('view').kwargs['profile']
        fields = super().get_field_names(*args, **kwargs)
        if profile == '':
            return fields
        return []


class AdministrativeAreaCreateSerializer(ThuxCreateSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_l10n_administrative_area_create'
        model = models.AdministrativeArea
        exclude = ('date_create', 'date_last_modify', 'creator', 'last_modifier')

    def get_field_names(self, *args, **kwargs):
        profile = self.context.get('view').kwargs['profile']
        fields = super().get_field_names(*args, **kwargs)
        if profile == '':
            return fields
        return []

    def to_representation(self, instance):
        return AdministrativeAreaListSerializer(instance, context=self.context).data


class AdministrativeAreaUpdateSerializer(ThuxUpdateSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_l10n_administrative_area_update'
        model = models.AdministrativeArea
        exclude = ('date_create', 'date_last_modify', 'creator', 'last_modifier')

    def get_field_names(self, *args, **kwargs):
        profile = self.context.get('view').kwargs['profile']
        fields = super().get_field_names(*args, **kwargs)
        if profile == '':
            return fields
        return []

    def to_representation(self, instance):
        return AdministrativeAreaRetrieveSerializer(instance, context=self.context).data


class AdministrativeAreaPartialUpdateSerializer(ThuxPartialUpdateSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_l10n_administrative_area_partial_update'
        model = models.AdministrativeArea
        exclude = ('date_create', 'date_last_modify', 'creator', 'last_modifier')

    def get_field_names(self, *args, **kwargs):
        profile = self.context.get('view').kwargs['profile']
        fields = super().get_field_names(*args, **kwargs)
        if profile == '':
            return fields
        return []

    def to_representation(self, instance):
        return AdministrativeAreaRetrieveSerializer(instance, context=self.context).data


class AdministrativeAreaEnableSerializer(ThuxEnableSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_l10n_administrative_area_enable'
        model = models.AdministrativeArea
        fields = ()

    def update(self, instance, validated_data):
        instance.status = 1
        instance.save()
        return instance

    def to_representation(self, instance):
        return AdministrativeAreaRetrieveSerializer(instance, context=self.context).data


class AdministrativeAreaDisableSerializer(ThuxDisableSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_l10n_administrative_area_disable'
        model = models.AdministrativeArea
        fields = ()

    def update(self, instance, validated_data):
        instance.status = 0
        instance.save()
        return instance

    def to_representation(self, instance):
        return AdministrativeAreaRetrieveSerializer(instance, context=self.context).data

==> thx-l10n-0.0.2.tar.gz: thx-l10n-0.0.2/thx/l10n/api/version1/serializers.py <==
# -*- coding: utf-8 -*-

from rest_framework import serializers

from ... import models
from thx.api.serializers import (
    ThuxListSerializerMixin, ThuxRetrieveSerializerMixin, ThuxCreateSerializerMixin,
    ThuxUpdateSerializerMixin, ThuxPartialUpdateSerializerMixin, ThuxStatusSerializerMixin,
    ThuxEnableSerializerMixin, ThuxDisableSerializerMixin
)
from thx.role.core.serializers import ThuxRoleSerializerMixin


# COUNTRY
class CountrySerializer(ThuxRoleSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_l10n_country'
        model = models.Country
        fields = '__all__'


class CountryListSerializer(ThuxRoleSerializerMixin, ThuxListSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_l10n_country_list'
        model = models.Country
        fields = '__all__'


class CountryRetrieveSerializer(ThuxRoleSerializerMixin, ThuxRetrieveSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_l10n_country_retrieve'
        model = models.Country
        fields = '__all__'


class CountryCreateSerializer(ThuxRoleSerializerMixin, ThuxCreateSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_l10n_country_create'
        model = models.Country
        exclude = ('date_create', 'date_last_modify', 'creator', 'last_modifier')

    def to_representation(self, instance):
        return CountryListSerializer(instance, context=self.context).data


class CountryUpdateSerializer(ThuxRoleSerializerMixin, ThuxUpdateSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_l10n_country_update'
        model = models.Country
        exclude = ('date_create', 'date_last_modify', 'creator', 'last_modifier')

    def to_representation(self, instance):
        return CountryRetrieveSerializer(instance, context=self.context).data


class CountryPartialUpdateSerializer(
    ThuxRoleSerializerMixin, ThuxPartialUpdateSerializerMixin, serializers.ModelSerializer
):
    class Meta:
        ref_name = 'v1_l10n_country_partial_update'
        model = models.Country
        exclude = ('date_create', 'date_last_modify', 'creator', 'last_modifier')

    def to_representation(self, instance):
        return CountryRetrieveSerializer(instance, context=self.context).data


class CountryEnableSerializer(ThuxRoleSerializerMixin, ThuxEnableSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_l10n_country_enable'
        model = models.Country
        fields = ()

    def update(self, instance, validated_data):
        instance.status = 1
        instance.save()
        return instance

    def to_representation(self, instance):
        return CountryRetrieveSerializer(instance, context=self.context).data


class CountryDisableSerializer(ThuxRoleSerializerMixin, ThuxDisableSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_l10n_country_disable'
        model = models.Country
        fields = ()

    def update(self, instance, validated_data):
        instance.status = 0
        instance.save()
        return instance

    def to_representation(self, instance):
        return CountryRetrieveSerializer(instance, context=self.context).data


# ADMINISTRATIVE AREA
class AdministrativeAreaSerializer(ThuxRoleSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_l10n_administrative_area'
        model = models.AdministrativeArea
        fields = '__all__'


class AdministrativeAreaListSerializer(ThuxRoleSerializerMixin, ThuxListSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_l10n_administrative_area_list'
        model = models.AdministrativeArea
        fields = '__all__'


class AdministrativeAreaRetrieveSerializer(
    ThuxRoleSerializerMixin, ThuxRetrieveSerializerMixin, serializers.ModelSerializer
):
    class Meta:
        ref_name = 'v1_l10n_administrative_area_retrieve'
        model = models.AdministrativeArea
        fields = '__all__'


class AdministrativeAreaCreateSerializer(
    ThuxRoleSerializerMixin, ThuxCreateSerializerMixin, serializers.ModelSerializer
):
    class Meta:
        ref_name = 'v1_l10n_administrative_area_create'
        model = models.AdministrativeArea
        exclude = ('date_create', 'date_last_modify', 'creator', 'last_modifier')

    def to_representation(self, instance):
        return AdministrativeAreaListSerializer(instance, context=self.context).data


class AdministrativeAreaUpdateSerializer(
    ThuxRoleSerializerMixin, ThuxUpdateSerializerMixin, serializers.ModelSerializer
):
    class Meta:
        ref_name = 'v1_l10n_administrative_area_update'
        model = models.AdministrativeArea
        exclude = ('date_create', 'date_last_modify', 'creator', 'last_modifier')

    def to_representation(self, instance):
        return AdministrativeAreaRetrieveSerializer(instance, context=self.context).data


class AdministrativeAreaPartialUpdateSerializer(
    ThuxRoleSerializerMixin, ThuxPartialUpdateSerializerMixin, serializers.ModelSerializer
):
    class Meta:
        ref_name = 'v1_l10n_administrative_area_partial_update'
        model = models.AdministrativeArea
        exclude = ('date_create', 'date_last_modify', 'creator', 'last_modifier')

    def to_representation(self, instance):
        return AdministrativeAreaRetrieveSerializer(instance, context=self.context).data


class AdministrativeAreaEnableSerializer(
    ThuxRoleSerializerMixin, ThuxEnableSerializerMixin, serializers.ModelSerializer
):
    class Meta:
        ref_name = 'v1_l10n_administrative_area_enable'
        model = models.AdministrativeArea
        fields = ()

    def update(self, instance, validated_data):
        instance.status = 1
        instance.save()
        return instance

    def to_representation(self, instance):
        return AdministrativeAreaRetrieveSerializer(instance, context=self.context).data


class AdministrativeAreaDisableSerializer(
    ThuxRoleSerializerMixin, ThuxDisableSerializerMixin, serializers.ModelSerializer
):
    class Meta:
        ref_name = 'v1_l10n_administrative_area_disable'
        model = models.AdministrativeArea
        fields = ()

    def update(self, instance, validated_data):
        instance.status = 0
        instance.save()
        return instance

    def to_representation(self, instance):
        return AdministrativeAreaRetrieveSerializer(instance, context=self.context).data
